@@ -229,11 +229,9 @@ func sortedLines(data []byte) []byte {
 }
 
 func TestGAWK(t *testing.T) {
-	skip := map[string]bool{ // TODO: fix these
+	skip := map[string]bool{ // TODO: fix these (at least the ones that are bugs)
 		"getline":  true, // getline syntax issues (may be okay, see grammar notes at http://pubs.opengroup.org/onlinepubs/007904975/utilities/awk.html#tag_04_06_13_14)
 		"getline3": true, // getline syntax issues (similar to above)
-		"getline5": true, // getline syntax issues (similar to above)
-		"inputred": true, // getline syntax issues (similar to above)
 
 		"gsubtst7":     true, // something wrong with gsub or field split/join
 		"splitwht":     true, // other awks handle split(s, a, " ") differently from split(s, a, / /)
@@ -244,11 +242,15 @@ func TestGAWK(t *testing.T) {
 
 		"rscompat": true, // GoAWK allows multi-char RS by default
 		"rsstart2": true, // GoAWK ^ and $ anchors match beginning and end of line, not file (unlike Gawk)
+
+		"hex2":   true, // GoAWK allows hex numbers / floating point (per POSIX)
+		"strtod": true, // GoAWK allows hex numbers / floating point (per POSIX)
 	}
 
 	dontRunOnWindows := map[string]bool{
 		"delargv":  true, // reads from /dev/null
 		"eofsplit": true, // reads from /etc/passwd
+		"getline5": true, // removes a file while it's open
 		"iobug1":   true, // reads from /dev/null
 	}
 
@@ -363,6 +365,7 @@ func TestCommandLine(t *testing.T) {
 		{[]string{"-v", "x=42", "-v", "y=foo", `BEGIN { print x, y }`}, "", "42 foo\n", ""},
 		{[]string{"-v", "RS=;", `$0`}, "a b;c\nd;e", "a b\nc\nd\ne\n", ""},
 		{[]string{"-vRS=;", `$0`}, "a b;c\nd;e", "a b\nc\nd\ne\n", ""},
+		{[]string{"-v", `X=x\ty`, `BEGIN { printf X }`}, "", "x\ty", ""},
 
 		// ARGV/ARGC handling
 		{[]string{`
@@ -392,6 +395,7 @@ func TestCommandLine(t *testing.T) {
 		{[]string{"-v", "A=1", "-f", "testdata/g.3", "B=2", "testdata/test.countries"}, "",
 			"A=1, B=0\n\tARGV[1] = B=2\n\tARGV[2] = testdata/test.countries\nA=1, B=2\n", ""},
 		{[]string{`END { print (x==42) }`, "x=42.0"}, "", "1\n", ""},
+		{[]string{`END { printf X }`, `X=a\tb`}, "", "a\tb", ""},
 		{[]string{"-v", "x=42.0", `BEGIN { print (x==42) }`}, "", "1\n", ""},
 		{[]string{`BEGIN { print(ARGV[1]<2, ARGV[2]<2); ARGV[1]="10"; ARGV[2]="10x"; print(ARGV[1]<2, ARGV[2]<2) }`,
 			"10", "10x"}, "", "0 1\n1 1\n", ""},
@@ -453,6 +457,11 @@ func runGoAWK(args []string, stdin string) (stdout, stderr string, err error) {
 }
 
 func runAWKs(t *testing.T, testArgs []string, testStdin, testOutput, testError string) {
+	var args []string
+	if strings.Contains(awkExe, "gawk") {
+		args = append(args, "--posix")
+	}
+	args = append(args, testArgs...)
 	cmd := exec.Command(awkExe, testArgs...)
 	if testStdin != "" {
 		cmd.Stdin = strings.NewReader(testStdin)
@@ -679,7 +688,7 @@ func TestCSVDocExamples(t *testing.T) {
 			truncated = false
 		} else if inTest {
 			switch line {
-			case "```":
+			case "```", "":
 				runTest()
 				inTest = false
 			case "...":
