@@ -430,6 +430,7 @@ type csvSplitter struct {
 
 	recordBuffer []byte
 	fieldIndexes []int
+	noBOMCheck   bool
 
 	fields        *[]string
 	setFieldNames func(names []string)
@@ -442,6 +443,13 @@ type csvSplitter struct {
 // We don't support all encoding/csv features: FieldsPerRecord is not
 // supported, LazyQuotes is always on, and TrimLeadingSpace is always off.
 func (s *csvSplitter) scan(data []byte, atEOF bool) (advance int, token []byte, err error) {
+	// Some CSV files are saved with a UTF-8 BOM at the start; skip it.
+	if !s.noBOMCheck && len(data) >= 3 && data[0] == 0xEF && data[1] == 0xBB && data[2] == 0xBF {
+		data = data[3:]
+		advance = 3
+		s.noBOMCheck = true
+	}
+
 	origData := data
 	if atEOF && len(data) == 0 {
 		// No more data, tell Scanner to stop.
@@ -587,6 +595,8 @@ parseField:
 		preIdx = idx
 	}
 
+	s.noBOMCheck = true
+
 	if s.rowNum == 0 && s.header {
 		// Set header field names and advance, but don't return a line (token).
 		s.rowNum++
@@ -731,7 +741,13 @@ func (p *interp) nextLine() (string, error) {
 				matches := varRegex.FindStringSubmatch(filename)
 				if len(matches) >= 3 {
 					// Yep, set variable to value and keep going
-					err := p.setVarByName(matches[1], matches[2])
+					name, val := matches[1], matches[2]
+					// Oddly, var=value args must interpret escapes (issue #129)
+					unescaped, err := Unescape(val)
+					if err == nil {
+						val = unescaped
+					}
+					err = p.setVarByName(name, val)
 					if err != nil {
 						return "", err
 					}
